class SystemPicturesController < ApplicationController
  layout 'test' if MagicNumber['test_layout']
  before_filter :authenticate_user!, :only => [:index, :show]
  before_filter :authenticate_admin!, :only => [:list, :browse, :new, :create]

  # GET /system_pictures
  # GET /system_pictures.json
  def index
    @page = SystemPicture.page params[:page]
    @page_size = SystemPicture.page_size params[:page_size]
    @system_pictures = SystemPicture.list(@page, @page_size)

    respond_to do |format|
      format.html # index.html.erb
      format.json { render json: @system_pictures.to_json(SystemPicture.list_json_opt) }
    end
  end

  # GET /system_pictures/1
  # GET /system_pictures/1.json
  def show
    @system_picture = SystemPicture.show(params[:id], @author)
    
    respond_to do |format|
      opt = {:type => @system_picture.mime_type, :disposition=>"inline"}
      format.png { send_data(@system_picture.restore, opt ) }
      format.gif { send_data(@system_picture.restore, opt ) }
      format.jpeg { send_data(@system_picture.restore, opt ) }
      format.html # show.html.erb
      format.json { render json: @system_picture.to_json(SystemPicture.show_json_opt)}
    end
  end

  def list
    @system_pictures = SystemPicture.all

    respond_to do |format|
      format.html { render layout: 'system' }
      format.json { render json: @system_pictures }
    end
  end

  def browse
    @system_picture = SystemPicture.find(params[:id])

    respond_to do |format|
      format.html { render layout: 'system' }
      format.json { render json: @system_picture}
    end
  end

  def new
    respond_to do |format|
      format.html # new.html.erb
    end
  end

  # POST /system_pictures
  # POST /system_pictures.json
  def create
    @imager = PettanImager.load set_image params[:system_picture][:file]

    respond_to do |format|
      @system_picture = SystemPicture.store @imager
      if @system_picture
        format.html { redirect_to @system_picture, notice: 'system picture was successfully created.' }
        format.json { render json: @system_picture.to_json(SystemPicture.show_json_opt), status: :created, location: @system_picture }
      else
        format.html { render action: "new" }
        format.json { render json: {}, status: :unprocessable_entity }
      end
    end
  end

end
